@@ -1,25 +1,31 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE, cache=FALSE--------------------------------------
+if(Sys.getenv("LOGNAME")=="andrewhooker") devtools::load_all("~/Documents/_PROJECTS/PopED/repos/PopED/")
+
+library(deSolve)
+library(Rcpp)
+
 knitr::opts_chunk$set(
   collapse = TRUE
   , comment = "#>"
   #, fig.width=6
-  #, cache = TRUE
+  , cache = TRUE
+  , fig.align = "center"
+  , out.width = "80%"
+  , autodep=TRUE
 )
 
-## ----eval=FALSE----------------------------------------------------------
-#  system.file("examples", package="PopED")
+## ----eval=TRUE----------------------------------------------------------------
+ex_dir <- system.file("examples", package="PopED")
+list.files(ex_dir)
 
-## ----eval=FALSE----------------------------------------------------------
-#  ex_dir <- system.file("examples", package="PopED")
-#  list.files(ex_dir)
-
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  file_name <- "ex.1.a.PK.1.comp.oral.md.intro.R"
+#  
 #  ex_file <- system.file("examples",file_name,package="PopED")
 #  file.copy(ex_file,tempdir(),overwrite = T)
 #  file.edit(file.path(tempdir(),file_name))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(PopED)
 f_pkpdmodel <- function(model_switch,xt,parameters,poped.db){
   with(as.list(parameters),{
@@ -39,7 +45,7 @@ f_pkpdmodel <- function(model_switch,xt,parameters,poped.db){
   })
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ## -- Residual Error function
 ## -- Proportional PK + additive PD
 f_Err <- function(model_switch,xt,parameters,epsi,poped.db){
@@ -58,7 +64,7 @@ f_Err <- function(model_switch,xt,parameters,epsi,poped.db){
   return(list( y= y,poped.db =poped.db )) 
 }
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 f_etaToParam <- function(x,a,bpop,b,bocc){
   parameters=c( 
     CL=bpop[1]*exp(b[1]),
@@ -71,36 +77,42 @@ f_etaToParam <- function(x,a,bpop,b,bocc){
   return( parameters ) 
 }
 
-## ------------------------------------------------------------------------
-poped.db <- create.poped.database(ff_fun=f_pkpdmodel,
-                                  fError_fun=f_Err,
-                                  fg_fun=f_etaToParam,
-                                  sigma=diag(c(0.15,0.015)),
-                                  bpop=c(CL=0.5,V=0.2,E0=1,EMAX=1,EC50=1),  
-                                  d=c(CL=0.09,V=0.09,E0=0.04,EC50=0.09), 
-                                  groupsize=20,
-                                  m=3,
-                                  xt=c( 0.33,0.66,0.9,5,0.1,1,2,5),
-                                  minxt=0,
-                                  maxxt=5,
-                                  bUseGrouped_xt=1,
-                                  model_switch=c(1,1,1,1,2,2,2,2),
-                                  a=list(c(DOSE=0),c(DOSE=1),c(DOSE=2)),
-                                  maxa=c(DOSE=10),
-                                  mina=c(DOSE=0))
+## -----------------------------------------------------------------------------
+poped.db <- create.poped.database(
+  
+  # Model
+  ff_fun=f_pkpdmodel,
+  fError_fun=f_Err,
+  fg_fun=f_etaToParam,
+  sigma=diag(c(0.15,0.015)),
+  bpop=c(CL=0.5,V=0.2,E0=1,EMAX=1,EC50=1),  
+  d=c(CL=0.09,V=0.09,E0=0.04,EC50=0.09), 
+  
+  # Design
+  groupsize=20,
+  m=3,
+  xt = c(0.33,0.66,0.9,5,0.1,1,2,5),
+  model_switch=c(1,1,1,1,2,2,2,2),
+  a=list(c(DOSE=0),c(DOSE=1),c(DOSE=2)),
 
+  # Design space
+  minxt=0,
+  maxxt=5,
+  bUseGrouped_xt=1,
+  maxa=c(DOSE=10),
+  mina=c(DOSE=0))
 
+## ----simulate_multi-response_model--------------------------------------------
+plot_model_prediction(
+  poped.db,PI=TRUE,
+  facet_scales="free",
+  separate.groups=TRUE,
+  model.names=c("PK","PD")) 
 
-## ----simulate_multi-response_model---------------------------------------
-plot_model_prediction(poped.db,IPRED=TRUE,DV=TRUE,facet_scales="free",
-                      separate.groups=TRUE,
-                      model.names=c("PK","PD")) 
-
-## ----eval=TRUE-----------------------------------------------------------
-library(Rcpp)
+## ----eval=TRUE----------------------------------------------------------------
 library(deSolve)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 PK.2.comp.oral.ode <- function(Time, State, Pars){
   with(as.list(c(State, Pars)), {    
     dA1 <- -KA*A1 
@@ -110,21 +122,30 @@ PK.2.comp.oral.ode <- function(Time, State, Pars){
   })
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ff.PK.2.comp.oral.md.ode <- function(model_switch, xt, parameters, poped.db){
   with(as.list(parameters),{
-    A_ini <- c(A1=0, A2=0, A3=0)
-    times_xt <- drop(xt)
-    dose_times = seq(from=0,to=max(times_xt),by=TAU)
-    eventdat <- data.frame(var = c("A1"), 
-                           time = dose_times,
-                           value = c(DOSE), method = c("add"))
-    times <- sort(c(times_xt,dose_times))
     
-    # Here "PK.2.comp.oral.ode" is equivalent to the pre-compiled version "two_comp_oral_ode_Rcpp".
+    # initial conditions of ODE system
+    A_ini <- c(A1=0, A2=0, A3=0)
+
+    #Set up time points to get ODE solutions
+    times_xt <- drop(xt) # sample times
+    times_start <- c(0) # add extra time for start of study
+    times_dose = seq(from=0,to=max(times_xt),by=TAU) # dose times
+    times <- unique(sort(c(times_start,times_xt,times_dose))) # combine it all
+    
+    # Dosing
+    dose_dat <- data.frame(
+      var = c("A1"), 
+      time = times_dose,
+      value = c(DOSE*Favail), 
+      method = c("add")
+    )
+    
     out <- ode(A_ini, times, PK.2.comp.oral.ode, parameters,
-               events = list(data = eventdat))#atol=1e-13,rtol=1e-13)
-    y = out[, "A2"]/(V1/Favail)
+               events = list(data = dose_dat))#atol=1e-13,rtol=1e-13)
+    y = out[, "A2"]/V1
     y=y[match(times_xt,out[,"time"])]
     y=cbind(y)
     return(list(y=y,poped.db=poped.db))
@@ -132,7 +153,7 @@ ff.PK.2.comp.oral.md.ode <- function(model_switch, xt, parameters, poped.db){
 }
 
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 fg <- function(x,a,bpop,b,bocc){
   parameters=c( CL=bpop[1]*exp(b[1]),
                 V1=bpop[2],
@@ -145,77 +166,95 @@ fg <- function(x,a,bpop,b,bocc){
   return( parameters ) 
 }
 
-## ------------------------------------------------------------------------
-discrete_a <- cell(2,1)
+## -----------------------------------------------------------------------------
+poped.db <- create.poped.database(
+  
+  # Model
+  ff_fun="ff.PK.2.comp.oral.md.ode",
+  fError_fun="feps.add.prop",
+  fg_fun="fg",
+  sigma=c(prop=0.1^2,add=0.05^2),
+  bpop=c(CL=10,V1=100,KA=1,Q= 3.0, V2= 40.0, Favail=1),
+  d=c(CL=0.15^2,KA=0.25^2),
+  notfixed_bpop=c(1,1,1,1,1,0),
+  
+  # Design
+  groupsize=20,
+  m=1,      #number of groups
+  xt=c( 48,50,55,65,70,85,90,120),
+  
+  # Design space 
+  minxt=0,
+  maxxt=144,
+  discrete_xt = list(0:144),
+  a=c(DOSE=100,TAU=24),
+  discrete_a = list(DOSE=seq(0,1000,by=100),TAU=8:24))
 
-poped.db <- create.poped.database(ff_fun="ff.PK.2.comp.oral.md.ode",
-                                  fError_fun="feps.add.prop",
-                                  fg_fun="fg",
-                                  groupsize=20,
-                                  m=1,      #number of groups
-                                  sigma=c(prop=0.1^2,add=0.05^2),
-                                  bpop=c(CL=10,V1=100,KA=1,Q= 3.0, V2= 40.0, Favail=1),
-                                  d=c(CL=0.15^2,KA=0.25^2),
-                                  notfixed_bpop=c(1,1,1,1,1,0),
-                                  xt=c( 48,50,55,65,70,85,90,120), 
-                                  minxt=0,
-                                  maxxt=144,
-                                  discrete_xt = list(0:144),
-                                  a=c(DOSE=100,TAU=24),
-                                  maxa=c(DOSE=1000,TAU=24),
-                                  mina=c(DOSE=0,TAU=8),
-                                  discrete_a = list(DOSE=seq(0,1000,by=100),TAU=8:24))
+## ----simulate_ODE_model-------------------------------------------------------
+plot_model_prediction(poped.db,model_num_points = 500)
 
-## ----simulate_ODE_model--------------------------------------------------
-plot_model_prediction(poped.db)
-
-## ------------------------------------------------------------------------
-cppFunction('List two_comp_oral_ode_Rcpp(double Time, NumericVector A, NumericVector Pars) {
-            int n = A.size();
-            NumericVector dA(n);
+## -----------------------------------------------------------------------------
+library(Rcpp)
+cppFunction(
+  'List two_comp_oral_ode_Rcpp(double Time, NumericVector A, NumericVector Pars) {
+     int n = A.size();
+     NumericVector dA(n);
             
-            double CL = Pars[0];
-            double V1 = Pars[1];
-            double KA = Pars[2];
-            double Q  = Pars[3];
-            double V2 = Pars[4];
+     double CL = Pars[0];
+     double V1 = Pars[1];
+     double KA = Pars[2];
+     double Q  = Pars[3];
+     double V2 = Pars[4];
             
-            dA[0] = -KA*A[0];
-            dA[1] = KA*A[0] - (CL/V1)*A[1] - Q/V1*A[1] + Q/V2*A[2];
-            dA[2] = Q/V1*A[1] - Q/V2*A[2];
-            return List::create(dA);
-            }')
+     dA[0] = -KA*A[0];
+     dA[1] = KA*A[0] - (CL/V1)*A[1] - Q/V1*A[1] + Q/V2*A[2];
+     dA[2] = Q/V1*A[1] - Q/V2*A[2];
+     return List::create(dA);
+  }')
 
-## ---- echo=FALSE---------------------------------------------------------
+## -----------------------------------------------------------------------------
 ff.PK.2.comp.oral.md.ode.Rcpp <- function(model_switch, xt, parameters, poped.db){
   with(as.list(parameters),{
-    A_ini <- c(A1=0, A2=0, A3=0)
-    times_xt <- drop(xt)
-    dose_times = seq(from=0,to=max(times_xt),by=TAU)
-    eventdat <- data.frame(var = c("A1"), 
-                           time = dose_times,
-                           value = c(DOSE), method = c("add"))
-    times <- sort(c(times_xt,dose_times))
     
-    # Here "PK.2.comp.oral.ode" is equivalent to the pre-compiled version "two_comp_oral_ode_Rcpp".
+    # initial conditions of ODE system
+    A_ini <- c(A1=0, A2=0, A3=0)
+
+    #Set up time points to get ODE solutions
+    times_xt <- drop(xt) # sample times
+    times_start <- c(0) # add extra time for start of study
+    times_dose = seq(from=0,to=max(times_xt),by=TAU) # dose times
+    times <- unique(sort(c(times_start,times_xt,times_dose))) # combine it all
+    
+    # Dosing
+    dose_dat <- data.frame(
+      var = c("A1"), 
+      time = times_dose,
+      value = c(DOSE*Favail), 
+      method = c("add")
+    )
+    
+    # Here "two_comp_oral_ode_Rcpp" is equivalent 
+    # to the non-compiled version "PK.2.comp.oral.ode".
     out <- ode(A_ini, times, two_comp_oral_ode_Rcpp, parameters,
-               events = list(data = eventdat))#atol=1e-13,rtol=1e-13)
-    y = out[, "A2"]/(V1/Favail)
+               events = list(data = dose_dat))#atol=1e-13,rtol=1e-13)
+    y = out[, "A2"]/V1
     y=y[match(times_xt,out[,"time"])]
     y=cbind(y)
     return(list(y=y,poped.db=poped.db))
   })
 }
 
-## ------------------------------------------------------------------------
-poped.db.Rcpp <- create.poped.database(poped.db,
-                                       ff_fun="ff.PK.2.comp.oral.md.ode.Rcpp")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
+poped.db.Rcpp <- create.poped.database(
+  poped.db,
+  ff_fun="ff.PK.2.comp.oral.md.ode.Rcpp")
+
+## -----------------------------------------------------------------------------
 tic(); eval <- evaluate_design(poped.db); toc()
 tic(); eval <- evaluate_design(poped.db.Rcpp); toc()
 
-## ---- echo=FALSE, results="hide"-----------------------------------------
+## ---- echo=FALSE, results="hide"----------------------------------------------
 cppFunction('List tmdd_qss_one_target_model_ode
             (double Time, NumericVector A, NumericVector Pars) {
             int n = A.size();
@@ -249,7 +288,7 @@ cppFunction('List tmdd_qss_one_target_model_ode
             return List::create(dA);
             }')
 
-## ----echo=FALSE, results="hide"------------------------------------------
+## ----echo=FALSE, results="hide"-----------------------------------------------
 sfg <- function(x,a,bpop,b,bocc){
   parameters=c( CL=bpop[1]*exp(b[1])  ,
                 V1=bpop[2]*exp(b[2])	,
@@ -268,7 +307,7 @@ sfg <- function(x,a,bpop,b,bocc){
   return(parameters) 
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tmdd_qss_one_target_model_compiled <- function(model_switch,xt,parameters,poped.db){
   with(as.list(parameters),{
     y=xt
@@ -307,7 +346,7 @@ tmdd_qss_one_target_model_compiled <- function(model_switch,xt,parameters,poped.
 }
 
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 tmdd_qss_one_target_model_ruv <- function(model_switch,xt,parameters,epsi,poped.db){
   returnArgs <- do.call(poped.db$model$ff_pointer,list(model_switch,xt,parameters,poped.db))
   y <- returnArgs[[1]]
@@ -320,7 +359,7 @@ tmdd_qss_one_target_model_ruv <- function(model_switch,xt,parameters,epsi,poped.
 }
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 xt <- zeros(6,30)
 study_1_xt <- matrix(rep(c(0.0417,0.25,0.5,1,3,7,14,21,28,35,42,49,56),8),nrow=4,byrow=TRUE)
 study_2_xt <- matrix(rep(c(0.0417,1,1,7,14,21,28,56,63,70,77,84,91,98,105),4),nrow=2,byrow=TRUE)
@@ -339,43 +378,54 @@ study_2_G_xt <- matrix(rep(c(14:28),4),nrow=2,byrow=TRUE)
 G_xt[1:4,1:26] <- study_1_G_xt
 G_xt[5:6,] <- study_2_G_xt
 
-## ------------------------------------------------------------------------
-poped.db.2 <- create.poped.database(ff_fun=tmdd_qss_one_target_model_compiled,
-                                    fError_fun=tmdd_qss_one_target_model_ruv,
-                                    fg_fun=sfg,
-                                    groupsize=rbind(6,6,6,6,100,100),
-                                    m=6,      #number of groups
-                                    sigma=c(0.04,0.0225),
-                                    bpop=c(CL=0.3,V1=3,Q=0.2,V2=3,FAVAIL=0.7,KA=0.5,VMAX=0,
-                                           KMSS=0,R0=0.1,KSSS=0.015,KDEG=10,KINT=0.05),
-                                    d=c(CL=0.09,V1=0.09,Q=0.04,V2=0.04,FAVAIL=0.04,
-                                        KA=0.16,VMAX=0,KMSS=0,R0=0.09,KSSS=0.09,KDEG=0.04,
-                                        KINT=0.04),
-                                    notfixed_bpop=c( 1,1,1,1,1,1,0,0,1,1,1,1),
-                                    notfixed_d=c( 1,1,1,1,1,1,0,0,1,1,1,1),
-                                    xt=xt,
-                                    model_switch=model_switch,
-                                    ni=rbind(26,26,26,26,30,30),
-                                    bUseGrouped_xt=1,
-                                    G_xt=G_xt,
-                                    a=list(c(DOSE=100, SC_FLAG=0),
-                                           c(DOSE=300, SC_FLAG=0),
-                                           c(DOSE=600, SC_FLAG=0),
-                                           c(DOSE=1000, SC_FLAG=1),
-                                           c(DOSE=600, SC_FLAG=0),
-                                           c(DOSE=1000, SC_FLAG=1)),
-                                    discrete_a = list(DOSE=seq(100,1000,by=100),
-                                                      SC_FLAG=c(0,1)))
+## -----------------------------------------------------------------------------
+poped.db.2 <- create.poped.database(
+  
+  # Model
+  ff_fun=tmdd_qss_one_target_model_compiled,
+  fError_fun=tmdd_qss_one_target_model_ruv,
+  fg_fun=sfg,
+  sigma=c(rtot_add=0.04,cfree_add=0.0225),
+  bpop=c(CL=0.3,V1=3,Q=0.2,V2=3,FAVAIL=0.7,KA=0.5,VMAX=0,
+         KMSS=0,R0=0.1,KSSS=0.015,KDEG=10,KINT=0.05),
+  d=c(CL=0.09,V1=0.09,Q=0.04,V2=0.04,FAVAIL=0.04,
+      KA=0.16,VMAX=0,KMSS=0,R0=0.09,KSSS=0.09,KDEG=0.04,
+      KINT=0.04),
+  notfixed_bpop=c( 1,1,1,1,1,1,0,0,1,1,1,1),
+  notfixed_d=c( 1,1,1,1,1,1,0,0,1,1,1,1),
+  
+  # Design
+  groupsize=rbind(6,6,6,6,100,100),
+  m=6,      #number of groups
+  xt=xt,
+  model_switch=model_switch,
+  ni=rbind(26,26,26,26,30,30),
+  a=list(c(DOSE=100, SC_FLAG=0),
+         c(DOSE=300, SC_FLAG=0),
+         c(DOSE=600, SC_FLAG=0),
+         c(DOSE=1000, SC_FLAG=1),
+         c(DOSE=600, SC_FLAG=0),
+         c(DOSE=1000, SC_FLAG=1)),
+  
+  # Design space
+  bUseGrouped_xt=1,
+  G_xt=G_xt,
+  discrete_a = list(DOSE=seq(100,1000,by=100),
+                    SC_FLAG=c(0,1)))
 
 
-## ----simulate_different_dose_regimen-------------------------------------
+## ----simulate_different_dose_regimen------------------------------------------
 plot_model_prediction(poped.db.2,facet_scales="free")
 
-## ------------------------------------------------------------------------
-eval_2 <- evaluate_design(poped.db.2);
-round(eval_2$rse)
+## ----results='hide'-----------------------------------------------------------
+eval_2 <- evaluate_design(poped.db.2)
+round(eval_2$rse) # in percent
 
-## ----model---------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
+knitr::kable(round(eval_2$rse),col.names = c("RSE in %")) #%>%  
+  #kableExtra::kable_styling("striped",full_width = F) 
+
+## ----model--------------------------------------------------------------------
 mod_1 <- function(model_switch,xt,parameters,poped.db){
   with(as.list(parameters),{
     y=xt
@@ -398,7 +448,7 @@ par_1 <- function(x,a,bpop,b,bocc){
   return( parameters ) 
 }
 
-## ----design--------------------------------------------------------------
+## ----design-------------------------------------------------------------------
 poped_db <- 
   create.poped.database(
     ff_fun=mod_1,
@@ -406,7 +456,7 @@ poped_db <-
     fError_fun=feps.add.prop,
     groupsize=50,
     m=1,
-    sigma=c(0.015,0.0015),
+    sigma=c(prop=0.015,add=0.0015),
     notfixed_sigma = c(1,0),
     bpop=c(CL=3.8,V=20,WT_CL=0.75,WT_V=1), 
     d=c(CL=0.05,V=0.05), 
@@ -417,13 +467,13 @@ poped_db <-
     a=c(WT=70)
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plot_model_prediction(poped_db)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 evaluate_design(poped_db)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped_db_2 <- 
   create.poped.database(
     ff_fun=mod_1,
@@ -431,8 +481,8 @@ poped_db_2 <-
     fError_fun=feps.add.prop,
     groupsize=1,
     m=50,
-    sigma=c(0.015,0.0015),
-    notfixed_sigma = c(1,0),
+    sigma=c(prop=0.015,add=0.0015),
+    notfixed_sigma = c(prop=1,add=0),
     bpop=c(CL=3.8,V=20,WT_CL=0.75,WT_V=1), 
     d=c(CL=0.05,V=0.05), 
     xt=c(1,2,4,6,8,24),
@@ -443,12 +493,47 @@ poped_db_2 <-
   )
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ev <- evaluate_design(poped_db_2) 
 round(ev$ofv,1)
+
+## ----results='hide'-----------------------------------------------------------
 round(ev$rse)
 
-## ------------------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
+knitr::kable(round(ev$rse),col.names = c("RSE in %")) #%>%  
+  #kableExtra::kable_styling("striped",full_width = FALSE) 
+
+## ---- cache=TRUE,results='hide'-----------------------------------------------
+nsim <- 30
+rse_list <- c()
+for(i in 1:nsim){
+  poped_db_tmp <- 
+    create.poped.database(
+      ff_fun=mod_1,
+      fg_fun=par_1,
+      fError_fun=feps.add.prop,
+      groupsize=1,
+      m=50,
+      sigma=c(prop=0.015,add=0.0015),
+      notfixed_sigma = c(1,0),
+      bpop=c(CL=3.8,V=20,WT_CL=0.75,WT_V=1), 
+      d=c(CL=0.05,V=0.05), 
+      xt=c( 1,2,4,6,8,24),
+      minxt=0,
+      maxxt=24,
+      bUseGrouped_xt=1,
+      a=as.list(rnorm(50,mean = 70,sd=10)))
+  rse_tmp <- evaluate_design(poped_db_tmp)$rse
+  rse_list <- rbind(rse_list,rse_tmp)
+}
+(rse_quant <- apply(rse_list,2,quantile))
+
+## ----echo=FALSE---------------------------------------------------------------
+knitr::kable(as.data.frame(rse_quant),digits = 2)#,col.names = c("RSE in %")) #%>%  
+  #kableExtra::kable_styling("striped",full_width = FALSE) 
+
+## -----------------------------------------------------------------------------
 sfg <- function(x,a,bpop,b,bocc){
   parameters=c( CL_OCC_1=bpop[1]*exp(b[1]+bocc[1,1]),
                 CL_OCC_2=bpop[1]*exp(b[1]+bocc[1,2]),
@@ -459,7 +544,7 @@ sfg <- function(x,a,bpop,b,bocc){
   return( parameters ) 
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 cppFunction(
   'List one_comp_oral_ode(double Time, NumericVector A, NumericVector Pars) {
    int n = A.size();
@@ -501,7 +586,7 @@ ff.ode.rcpp <- function(model_switch, xt, parameters, poped.db){
 }
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db <- 
   create.poped.database(
     ff_fun=ff.ode.rcpp,
@@ -509,7 +594,7 @@ poped.db <-
     fg_fun=sfg,
     bpop=c(CL=3.75,V=72.8,KA=0.25), 
     d=c(CL=0.25^2,V=0.09,KA=0.09), 
-    sigma=c(0.04,5e-6),
+    sigma=c(prop=0.04,add=5e-6),
     notfixed_sigma=c(0,0),
     docc = matrix(c(0,0.09,0),nrow = 1),
     m=2,
@@ -523,24 +608,29 @@ poped.db <-
     mina=c(DOSE=0,TAU=24)
   )
 
-## ----simulate_IOV_without_IIV--------------------------------------------
-plot_model_prediction(poped.db, model_num_points = 300)
-
-## ----simulate_IOV_with_IIV-----------------------------------------------
+## ----simulate_IOV_with_IIV----------------------------------------------------
 library(ggplot2)
 set.seed(123)
-plot_model_prediction(poped.db, PRED=F,IPRED=F, 
-                      separate.groups=T, model_num_points = 300, 
-                      groupsize_sim = 1,
-                      IPRED.lines = T, alpha.IPRED.lines=0.6,
-                      sample.times = F
-                      ) + geom_vline(xintercept = 24*6,color="red")
+plot_model_prediction(
+  poped.db, 
+  PRED=F,IPRED=F, 
+  separate.groups=T, 
+  model_num_points = 300, 
+  groupsize_sim = 1,
+  IPRED.lines = T, 
+  alpha.IPRED.lines=0.6,
+  sample.times = F
+) + geom_vline(xintercept = 24*6,color="red")
 
-## ------------------------------------------------------------------------
+## ----results='hide'-----------------------------------------------------------
 ev <- evaluate_design(poped.db)
 round(ev$rse)
 
-## ---- echo=FALSE, results="hide"-----------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
+knitr::kable(round(ev$rse),col.names = c("RSE in %")) #%>%  
+  #kableExtra::kable_styling("striped",full_width = FALSE) 
+
+## ---- echo=FALSE, results="hide"----------------------------------------------
 ff <- function(model_switch,xt,parameters,poped.db){
   ##-- Model: One comp first order absorption
   with(as.list(parameters),{
@@ -580,7 +670,7 @@ poped.db <-
     bpop=c(CL=0.15, V=8, KA=1.0, Favail=1), 
     notfixed_bpop=c(1,1,1,0),
     d=c(CL=0.07, V=0.02, KA=0.6), 
-    sigma=0.01,
+    sigma=c(prop=0.01),
     groupsize=32,
     xt=c( 0.5,1,2,6,24,36,72,120),
     minxt=0,
@@ -588,7 +678,7 @@ poped.db <-
     a=70
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db_with <- 
   create.poped.database(
     ff_file="ff",
@@ -598,7 +688,7 @@ poped.db_with <-
     notfixed_bpop=c(1,1,1,0),
     d=c(CL=0.07, V=0.02, KA=0.6), 
     covd = c(.03,.1,.09),
-    sigma=0.01,
+    sigma=c(prop=0.01),
     groupsize=32,
     xt=c( 0.5,1,2,6,24,36,72,120),
     minxt=0,
@@ -606,86 +696,74 @@ poped.db_with <-
     a=70
   )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 (IIV <- poped.db_with$parameters$param.pt.val$d)
 cov2cor(IIV)
 
-## ----simulate_with_cov_matrix--------------------------------------------
+## ----simulate_with_cov_matrix-------------------------------------------------
 library(ggplot2)
-p1 <- plot_model_prediction(poped.db,IPRED=TRUE)+ylim(0,12)
-p2 <- plot_model_prediction(poped.db_with,IPRED=TRUE) +ylim(0,12)
-gridExtra::grid.arrange(p1, p2, nrow = 1)
+p1 <- plot_model_prediction(poped.db, PI=TRUE)+ylim(-0.5,12) 
+p2 <- plot_model_prediction(poped.db_with,PI=TRUE) +ylim(-0.5,12)
+gridExtra::grid.arrange(p1+ ggtitle("No covariance in BSV"), p2+ ggtitle("Covariance in BSV"), nrow = 1)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ev1 <- evaluate_design(poped.db)
 ev2 <- evaluate_design(poped.db_with)
 
-## ------------------------------------------------------------------------
-round(ev1$ofv,1)
-round(ev1$rse,1)
+## ----results="hide"-----------------------------------------------------------
+round(ev1$rse)
+round(ev2$rse)
 
-round(ev2$ofv,1)
-round(ev2$rse,1)
+## ----echo=FALSE,message=FALSE-------------------------------------------------
+tb1 <- tibble::tibble(" "=names(ev1$rse),
+         "Diagonal BSV"=ev1$rse)
 
-## ------------------------------------------------------------------------
+tb2 <- tibble::tibble(" "=names(ev2$rse),
+         "Covariance in BSV"=ev2$rse)
+
+tb_final <- dplyr::right_join(tb1,tb2)
+
+knitr::kable(tb_final,digits = 0) #%>%  
+  #kableExtra::kable_styling("striped",full_width = FALSE) 
+
+## ----results='hide'-----------------------------------------------------------
 ev1 <- evaluate_design(poped.db, fim.calc.type=0)
 ev2 <-evaluate_design(poped.db_with, fim.calc.type=0)
 
-round(ev1$ofv,1)
 round(ev1$rse,1)
-
-round(ev2$ofv,1)
 round(ev2$rse,1)
 
-## ---- echo = FALSE-------------------------------------------------------
-##-- Model: One comp first order absorption
-## -- Analytic solution for both mutiple and single dosing
-ff <- function(model_switch,xt,parameters,poped.db){
-  with(as.list(parameters),{
-    y=xt
-    N = floor(xt/TAU)+1
-    y=(DOSE*Favail/V)*(KA/(KA - CL/V)) * 
-      (exp(-CL/V * (xt - (N - 1) * TAU)) * (1 - exp(-N * CL/V * TAU))/(1 - exp(-CL/V * TAU)) - 
-         exp(-KA * (xt - (N - 1) * TAU)) * (1 - exp(-N * KA * TAU))/(1 - exp(-KA * TAU)))  
-    return(list( y=y,poped.db=poped.db))
-  })
-}
+## ----echo=FALSE,message=FALSE-------------------------------------------------
+tb1 <- tibble::tibble(" "=names(ev1$rse),
+         "Diagonal BSV"=ev1$rse)
 
-## ------------------------------------------------------------------------
-## -- parameter definition function 
-## -- names match parameters in function ff
-## -- note, covariate on clearance for pediatrics (using isPediatric x[1])
+tb2 <- tibble::tibble(" "=names(ev2$rse),
+         "Covariance in BSV"=ev2$rse)
+
+tb_final <- dplyr::right_join(tb1,tb2)
+
+knitr::kable(tb_final,digits = 0) #%>%  
+  #kableExtra::kable_styling("striped",full_width = FALSE) 
+
+## -----------------------------------------------------------------------------
 sfg <- function(x,a,bpop,b,bocc){
   parameters=c( 
     V=bpop[1]*exp(b[1]),
     KA=bpop[2]*exp(b[2]),
-    CL=bpop[3]*exp(b[3])*bpop[5]^x[1], # add covariate for pediatrics
+    CL=bpop[3]*exp(b[3])*bpop[5]^a[3], # add covariate for pediatrics
     Favail=bpop[4],
-    isPediatric = x[1],
+    isPediatric = a[3],
     DOSE=a[1],
     TAU=a[2])
   return( parameters ) 
 }
 
-## ---- echo=FALSE, results="hide"-----------------------------------------
-## -- Residual unexplained variablity (RUV) function
-## -- Additive + Proportional  
-feps <- function(model_switch,xt,parameters,epsi,poped.db){
-  returnArgs <- do.call(poped.db$model$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
-  y <- returnArgs[[1]]
-  poped.db <- returnArgs[[2]]
-  
-  y = y*(1+epsi[,1])+epsi[,2]
-  
-  return(list( y= y,poped.db =poped.db )) 
-}
-
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db <- 
   create.poped.database(
-    ff_fun="ff",
-    fg_fun="sfg",
-    fError_fun="feps",
+    ff_fun=ff.PK.1.comp.oral.md.CL,
+    fg_fun=sfg,
+    fError_fun=feps.add.prop,
     bpop=c(V=72.8,KA=0.25,CL=3.75,Favail=0.9,pedCL=0.8), 
     notfixed_bpop=c(1,1,1,0,1),
     d=c(V=0.09,KA=0.09,CL=0.25^2), 
@@ -695,26 +773,26 @@ poped.db <-
     groupsize=20,
     xt=c( 1,8,10,240,245),
     bUseGrouped_xt=1,
-    a=list(c(DOSE=20,TAU=24),c(DOSE=40, TAU=24)),
-    x=list(isPediatric = 0)
+    a=list(c(DOSE=20,TAU=24,isPediatric = 0),
+           c(DOSE=40, TAU=24,isPediatric = 0))
   )
 
-## ----simulate_adult------------------------------------------------------
+## ----simulate_adult-----------------------------------------------------------
 plot_model_prediction(poped.db, model_num_points = 300)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 (outAdult = evaluate_design(poped.db))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 evaluate_design(create.poped.database(poped.db, notfixed_bpop=c(1,1,1,0,0)))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db.ped <- 
   create.poped.database(
-    ff_fun="ff",
-    fg_fun="sfg",
-    fError_fun="feps",
+    ff_fun=ff.PK.1.comp.oral.md.CL,
+    fg_fun=sfg,
+    fError_fun=feps.add.prop,
     bpop=c(V=72.8,KA=0.25,CL=3.75,Favail=0.9,pedCL=0.8), 
     notfixed_bpop=c(1,1,1,0,1),
     d=c(V=0.09,KA=0.09,CL=0.25^2), 
@@ -724,18 +802,17 @@ poped.db.ped <-
     groupsize=6,
     xt=c( 1,2,6,240),
     bUseGrouped_xt=1,
-    a=list(c(DOSE=40,TAU=24)),
-    x=list(isPediatric = 1)
+    a=list(c(DOSE=40,TAU=24,isPediatric = 1))
   )
 
-## ----simulate_pediatrics-------------------------------------------------
+## ----simulate_pediatrics------------------------------------------------------
 plot_model_prediction(poped.db.ped, model_num_points = 300)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 evaluate_design(poped.db.ped)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db.all <- create.poped.database(
   poped.db.ped,
   prior_fim = outAdult$fim
@@ -743,10 +820,10 @@ poped.db.all <- create.poped.database(
 
 (out.all <- evaluate_design(poped.db.all))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 evaluate_power(poped.db.all, bpop_idx=5, h0=1, out=out.all)
 
-## ---- echo=FALSE, results="hide"-----------------------------------------
+## ---- echo=FALSE, results="hide"----------------------------------------------
 sfg <- function(x,a,bpop,b,bocc){
   ## -- parameter definition function 
   parameters=c(
@@ -767,7 +844,7 @@ ff <- function(model_switch,xt,parameters,poped.db){
   })
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bpop_vals <- c(CL=0.15, V=8, KA=1.0, Favail=1)
 bpop_vals_ed <- 
   cbind(ones(length(bpop_vals),1)*4, # log-normal distribution
@@ -776,7 +853,7 @@ bpop_vals_ed <-
 bpop_vals_ed["Favail",] <- c(0,1,0)
 bpop_vals_ed
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db <- 
   create.poped.database(
     ff_fun=ff,
@@ -795,13 +872,13 @@ poped.db <-
     maxa=100,
     ED_samp_size=20)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tic();evaluate_design(poped.db,d_switch=FALSE,ED_samp_size=20); toc()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tic();evaluate_design(poped.db,d_switch=FALSE,ED_samp_size=20); toc()
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 sfg <- function(x,a,bpop,b,bocc){
   ## -- parameter definition function 
   parameters=c(CL=bpop[1]*exp(b[1]),
@@ -821,7 +898,7 @@ ff <- function(model_switch,xt,parameters,poped.db){
   })
 }
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 poped.db <- 
   create.poped.database(
     ff_fun=ff,
@@ -841,10 +918,10 @@ poped.db <-
     ds_index=c(0,0,0,1,1,1,1,1), # size is number_of_non_fixed_parameters
     ofv_calc_type=6) # Ds OFV calculation
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 evaluate_design(poped.db)
 
-## ---- echo=FALSE, results="hide"-----------------------------------------
+## ---- echo=FALSE, results="hide"----------------------------------------------
 
 sfg <- function(x,a,bpop,b,bocc){
   ## -- parameter definition function 
@@ -891,6 +968,6 @@ poped.db <- create.poped.database(
 plot_model_prediction(poped.db)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 shrinkage(poped.db)
 
