@@ -14,6 +14,7 @@ out_1 <- poped_optim(poped.db,opt_a =TRUE,
                                      LS=list(line_length=2)),
                       iter_max = 1)
 
+
 # cost function
 # PRED at 120 hours
 crit_fcn <- function(poped.db,...){
@@ -103,6 +104,34 @@ out_3 <- poped_optim(poped.db,opt_a =TRUE,
                        maximize = F,
                        evaluate_fim = F)
   
+  # optimize distribution of individuals in 3 groups
+  poped_db_2 <- create.poped.database(ff_fun=ff.PK.1.comp.oral.sd.CL,
+                                    fg_fun=sfg,
+                                    fError_fun=feps.add.prop,
+                                    bpop=c(CL=0.15, V=8, KA=1.0, Favail=1), 
+                                    notfixed_bpop=c(1,1,1,0),
+                                    d=c(CL=0.07, V=0.02, KA=0.6), 
+                                    sigma=c(prop=0.01,add=0.25),
+                                    groupsize=32,
+                                    m=3,
+                                    xt=list(c( 0.5,1,2,6,8),c(36,72,120),
+                                            c(10,12,14,16,18,20,22,24)),
+                                    minxt=0.01,
+                                    maxxt=120,
+                                    a=c(DOSE=70),
+                                    mina=c(DOSE=0.01),
+                                    maxa=c(DOSE=100))
+  
+  opt_xt_inds <- 
+    poped_optim(poped_db_2,
+                opt_a =TRUE,
+                opt_inds = TRUE,
+                control = list(ARS=list(iter=2),
+                               BFGS=list(maxit=2),
+                               LS=list(line_length=2)),
+                iter_max = 1)
+  
+  
   
   ##############
   # E-family Optimization
